@@ -3,14 +3,16 @@
 from orbitkit import util
 from orbitkit.file_extractor.dispatcher import FileDispatcher
 from orbitkit import id_srv
+from orbitkit.lark_send import FeiShuTalkChatBot
 
 name = 'orbitkit'
 
-__version__ = '0.1.1'
+__version__ = '0.2.2'
 VERSION = __version__
 
 __all__ = [
     'util',
     'FileDispatcher',
+    'FeiShuTalkChatBot',
     'id_srv',
 ]
