@@ -5,5 +5,6 @@ class FileExtractorAudio(FileExtractor):
     def __init__(self):
         super().__init__()
 
-    def extract(self, file_obj):
+    def extract(self):
+        file_obj = self.file_obj
         pass
